#!/tmp/.ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZpErLZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZperl/bin/perl

use HTML::Template;
use ActiveState::Config qw( :path);
use PureMessage::Manager::Request::Safe ('PureMessage::Manager::Response::Quarantine::Enduser', import => [qw($REQUEST %in)] );
use PureMessage::Manager::Widget;
use PureMessage::Manager::Config qw(%config);

use PureMessage::Manager::Safe PureMessage::Enduser::Config, undef, qw( %enduser_config );
use PureMessage::Manager::Lang;
use PureMessage::Manager::Response::Quarantine::Enduser;
use PureMessage::List;
use strict;
use HTML::Entities;

my %vars;
our %config;

my $r = $REQUEST->get_response( 'PureMessage::Manager::Response::Quarantine::Enduser',
                                'stderr_to_stdout' =>1 );


my %PATHS = ( 'EXPIRE_SESSION' => ['session.args.session_expire','#duration','Session Expire'],
              'URL'            => ['enduser_url','#string','End User URL'],
              'QUERY_DELAY'    => ['limit.query_wait','#duration','Query Delay'],
              'USER_LIST'      => ['allow.users','#string','User List'],
              'REASONS'        => ['allow.reasons','#nospaces','Quarantine Reasons'],
              'TZ'             => ['gmt_offset','#duration','GMT Offset'],
           );




$r->{debug} = 0;
$r->add_help(text => "Help", tab => "quar", page => "mgr_quar_enduser_opt" );
$r->addRestartDlg(type=>'httpd');

$r->title(text('enduserf_options_title'));

my $action = $in{'action'};

$action = 'save' if $in{'save'};
$action = 'edit' if $in{'edit'};

# get template vars we always want
$vars{'ACTION'} = $action;

# revisit is always set when the form is submitted so this is the first view
# so if load isn't sent from the link to this page we should still have
# valid values
#
$in{'load'} = 1 if !$in{revisit};


if ($action =~ /save/) {
    $vars{'TITLE'} = &text('enduserf_options_title');
    $r->title(&text('enduserf_options_title'));
    if ( !hasValidateErrors() ) {
         commitUpdatedDataToDisk();
         # allow PM::Service::Config to not exist, like
         # for instance, if they have an older PM-Utils
         # without it.
          eval {
                require PureMessage::Service::Config;
                PureMessage::Service::Config::stale('httpd');
              };

    } 
} 
  putEditPage();


### start of subs


sub putEditPage() {

    $vars{HEADER} = $r->ThemeSectionHeader( title=> text('enduserf_options_header'))->output(); 
    
    my @FEATURES;
    
    if ($in{load}) {
       foreach my $fname (keys %PATHS) {
          my $conf = PureMessage::Enduser::Config->edit();
          my $node = path_node($conf->root,$PATHS{$fname}->[0]);
          if ($fname eq 'REASONS') {
            # we are expecting an array
            $vars{$fname} = $node ? join("\n",$node->values()) : '';
          } elsif($fname eq 'USER_LIST') {
            my %lists = map { $_->{id} => $_->{name} } PureMessage::List->Available();
            #my %lists = map { $_->{id} => $_->{description} } PureMessage::List->Available();
            $vars{$fname} = PureMessage::Manager::Widget->option_list('USER_LIST', \%lists, $node ? $node->value : '');
          } else {
            $vars{$fname} = $node ? $node->value_formatted() : '';
          }
       }
    } else {
      foreach my $fname (keys %PATHS) {
        $vars{$fname} = $in{$fname};
      }
    }
  
    my $tb = $r->ToolBar(
                        buttons => [[ { type=>'image',text=>'Save',name=>'save',icon=>'save'},
                                      { type=>'image',text=>'Cancel',href=>'../index.cgi',icon=>'cancel'},
                                   ]],
                        table=> [[1,3],['50%','50%']],
                      );
    $vars{FOOTER} = $r->ThemeSectionFooter(toolbar=>$tb)->output();
    $vars{REASONS} = encode_entities($vars{REASONS},'&<>"\/\'');
    $vars{URL} = encode_entities($vars{URL},'&<>"\/\'');

    $r->add_template( 'file'=>'tmpl/options.html', 'data'=>\%vars );
    $r->send();

}

sub commitUpdatedDataToDisk {
   
    my %values;
    
    eval {
      my $conf = PureMessage::Enduser::Config::edit();
      foreach my $k (keys %PATHS) {
         if ($k eq 'REASONS') {
	    my @v = @{$in{$k}};
            path_values($conf->root,$PATHS{$k}->[0],@v);
         } else {
            path_value($conf->root,$PATHS{$k}->[0],$in{$k});
         }
      }
      $conf->save();
      PureMessage::Enduser::Config::refresh();
    };

    if ($@) {
        # config died, deal with it
        $r->raise_error('error_index_saving_conf',$@);
        $r->error_dlg();
        $r->send();
        exit;
    }
    $r->addInfoBox( msg => text('message_update_ok'));
    $r->log('Update End User Features','','enduser', \%in);
}


sub hasValidateErrors {
    #$r->raise_error($) 
    #    unless $vars{max_days} =~ qr{^[0-9]+$};
    $in{tz} = '' unless $in{tz}; # validator won't check keys that don't exists in input
    $in{max_days} = '' unless $in{max_days}; # validator won't check keys that don't exists in input
                                             # so force this to exist
    my @reasons = map { $_ = lc }
                  grep { length } split(/[\r\s\n\t,;]/, $in{REASONS});
    $in{REASONS} = \@reasons;
    foreach my $k (keys %PATHS) {
       $REQUEST->typedecl($k, $PATHS{$k}->[1],$PATHS{$k}->[2]);
    }
    my @v_errors = $REQUEST->validate(\%in);
    if (@v_errors) {
        $r->raise_error(join("<br>", @v_errors));
    } 
    return $r->error() ? 1 : 0;
}



