package PureMessage::Enduser::Auth;
use HTML::Entities;

=head1 NAME

PureMessage::Enduser::Auth - Check an enduser's credentials

=head2 SYNOPSIS

  use PureMessage::Enduser::Auth qw(Authorize);

  if (my %info = Authorize($username,$password)) {
      # all is ok, $info has whatever info about this user that might be useful
      # but at a minimum their email
      print "Welcome, your email address is $info{email}\n";
  } else {
    # that combination didn't seem to work.. 
  }

=cut


use PureMessage::Enduser::Config qw(%config);
use PureMessage::Manager::Lang qw( mtext );
use Exporter;
our @ISA = qw(Exporter);
our @EXPORT_OK = qw( Authorize );


my $backends;
my $currently_configured;
my $_Authorize;

sub refresh {
    my %fake_config = @_; # used for unit tests
    $config{$_} = $fake_config{$_} foreach keys %fake_config;
    
    $backends = $config{'Authenticator'};
    $currently_configured = $config{'Authenticator'}->{$config{auth}};
    die mtext('auth_configuration_bad',encode_entities($config{auth},'&<>"\/\'')) unless $currently_configured;

    eval {
        my %auth_config = %{$currently_configured->{config}};
        $auth_config{prefix} = $config{prefix};
        eval "require $currently_configured->{module}"; # require is quite picky :(
        die $@ if $@;
        $_Authorize = &{"$currently_configured->{module}::init"}(%auth_config);
        #$_Authorize = \&{"$currently_configured->{module}::Authorize"};
        die mtext('auth_init_bad',$config{auth}) unless $_Authorize and ref($_Authorize) eq 'CODE';
    };

    if($@) {
      die $@;
      die mtext('auth_configuration_module_failure',$config{auth},$@);
    }

}

refresh();

=item Authorize($username,$password [,%options])


=cut

sub Authorize {
  my ($user,$pass,%options) = @_;
  my %info = &$_Authorize($user,$pass,%options);
  return %info;
}


1;


