package PureMessage::Enduser::Auth::DomainVerify;

use strict;
use base qw(Exporter);
use vars qw($VERSION @EXPORT_OK);
use Sys::Hostname;
use ActiveState::Config qw(:path);
use PureMessage::Version qw($PREFIX);
use Net::Domain qw(hostdomain);
use PureMessage::List;
use PureMessage::ListFile;

@EXPORT_OK = qw (verifyDomainName);

sub verifyDomainName{
    my $auth_mail = shift;
	my $active_mta;
	my $thisdomain;

	$active_mta = `pmx-config active_mta`;
	chomp($active_mta);

	my $test = hostdomain();
	if ($active_mta eq "postfix"){
	    my $p = ActiveState::Config->new();
	    $p->parse_file("$PREFIX/etc/install.conf", writable => 0);
	    my $tree = $p->root;
	    $thisdomain = path_value($tree, "inst_opts.postfix_mydomain");
	    $p->save;
	}
	else{
	   $thisdomain = hostdomain(); 
	}

    my @allowed_domains = get_allowed_domains();

    #Remove wildcards from entries
    $_ =~ s/^[*@!]+//g foreach @allowed_domains;

    #Push domain of application to allowed domains list
    push @allowed_domains, $thisdomain;

    my($user, $domain) = split /@/,$auth_mail;
    
    #Use a flag, which is set to 1 if provided domain matches the list of domains
	my $allow_domain = 0;
	foreach (@allowed_domains){
		#TODO: Skip empty lines
		if ($domain =~ m/$_/){
			$allow_domain = 1;
		}
	}

	return 1 if $allow_domain;
	return 0;
}

#Helper method which provides lists of allowed domains, these are defined in enduser-users file
sub get_allowed_domains {
    my $list = PureMessage::List->Available('EUWI-Authentication');
    my $domains;
    if($list && $list->{'source'} =~ s/^file://){
        $domains = PureMessage::ListFile->new($list->{'source'}, 'writable' => 1);
    }
    else {
        die "List $list cannot be found." unless $list;
    }
    return $domains->entries;
}

1;